@@ -43,7 +43,10 @@ def view_types(data, dropna=True):
 
     df_output['(unique)'] = [data[c].astype(str).nunique(dropna) for c in data.columns]
     df_output.columns = [columns_exch.get(str(x), x) for x in df_output.columns]
-    display(df_output.head(60))
+    if '_Jupyter' in globals():
+        display(df_output.head(60))
+    else:
+        print(df_output.head(60))
     print("{} rows x {} columns".format(*data.shape))
 
 def phrase_build(number, noun_forms=None, prefix_forms=None, grouping_symbol='`'):
@@ -104,6 +107,7 @@ def phrase_build(number, noun_forms=None, prefix_forms=None, grouping_symbol='`'
 
     return f'{prefix_forms[form_prefix]} {n} {noun_forms[form_noun]}'.strip()
 
+
 def read_urls_contents(urls_list, max_workers=10, session=None, parser=None, encoding=None, *, 
     max_retries=None, timeout=None, error_page_output=None, mute=False):
     """
@@ -173,4 +177,48 @@ def read_urls_contents(urls_list, max_workers=10, session=None, parser=None, enc
                 else:
                     error_page_output.write(f'Download error:\n{url}|{exc}')
     buf.seek(0)
-    return buf
\ No newline at end of file
+    print("URLs list download:   100%")
+    return buf
+
+
+def accel_steps(max_degree=10):
+    """
+    Increment yield-counter with acceleration
+
+    Parameters
+    ----------
+    max_degree : int, optional
+        Power of 2 to determine the maximum value of the counter, by default 10.
+
+    Returns
+    -------
+    int
+        counter value
+
+    2021-07-29 (c) Nikolay Ganibaev
+    """
+    for i in range(int(max_degree)):
+        for j in 1, 2, 5:
+            yield j*10**i
+
+
+def tune_steps(number=100):
+    """
+    Decrement yield-counter fast decrement counter for binary search from [1..number]
+
+    Parameters
+    ----------
+    number : int, optional
+        Upper limit of the search range. By default, 100.
+
+    Returns
+    -------
+    int
+        counter value
+
+    2021-07-29 (c) Nikolay Ganibaev
+    """
+    while number>1:
+        number -= number//2
+        yield number
+    yield 1
\ No newline at end of file
